@@ -35,6 +35,14 @@ func (s *backend) Rootless() bool {
 	return false
 }
 
+func (s *backend) NetNSDetached() bool {
+	return false
+}
+
+func (s *backend) ExtraEnv() []string {
+	return nil
+}
+
 func (s backend) Supports(feature string) bool {
 	if enabledFeatures := os.Getenv("BUILDKIT_TEST_ENABLE_FEATURES"); enabledFeatures != "" {
 		for _, enabledFeature := range strings.Split(enabledFeatures, ",") {
